@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.71'; # Moved out of developer's release
+our $VERSION = '0.72'; # Closer to 1.0!!!
 
 # Preloaded methods go here.
 
@@ -154,11 +154,11 @@ C<bug-algorithm-evolutionary@rt.cpan.org>.
 Main author and developer is J. J. Merelo, jmerelo (at) geneura.ugr.es
 who blogs at <a href='http://blojj.blogalia.com'>BloJJ</a> and
 twitters at <a
-href='http://twitter.com/jmerelo'>twitter.com/jjmerelo</a>. There have
+href='http://twitter.com/jjmerelo'>twitter.com/jjmerelo</a>. There have
 also been some contributions from Javi Garca, fjgc (at) decsai.ugr.es
 and Pedro Castillo, pedro (at) geneura.ugr.es. Patient users that have
 submitted bugs include <a
-href='http://barbacana.net'>jamarier</a>. Bugs, requests and any kind
+href='http://barbacana.net'>jamarier</a> and Mike Gajewski. Bugs, requests and any kind
 of comment are welcome. <a href='http://alexm.org'>Alex Muntada</a>,
 from the <a href='http://barcelona.pm.org/'>Barcelona Perl
 Mongers</a>, helped me to solve a problem with the Makefile.PL.
@@ -198,14 +198,14 @@ Some other examples are installed: check out L<tide_bitstring.pl>,
 
 =item L<Algorithm::Evolutionary::Op::CanonicalGA>.
 
-=item L<XML> for an explanation of the XML format used
+=item L<XML> for an explanation of the XML format used.
 
 =item L<POE::Component::Algorithm::Evolutionary> if you want to mix
-evolutionary algorithms with anything else easily
+evolutionary algorithms with anything else easily.
 
 You might also be interested in one of the other perl GA and
 evolutionary computation modules out there, such as
-L<AI::Genetic::Pro>
+L<AI::Genetic::Pro>.
 
 =back 
 
@@ -216,9 +216,9 @@ L<AI::Genetic::Pro>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/30 07:48:48 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.6 2009/07/30 07:48:48 jmerelo Exp $ 
+  CVS Info: $Date: 2009/10/14 18:33:12 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.9 2009/10/14 18:33:12 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.6 $
+  $Revision: 3.9 $
 
 =cut
