@@ -44,7 +44,7 @@ package Algorithm::Evolutionary::Op::QuadXOver;
 
 use lib qw( ../../.. );
 
-our ($VERSION) = ( '$Revision: 3.0 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) = ( '$Revision: 3.1 $ ' =~ /(\d+\.\d+)/ );
 
 use Carp;
 
@@ -71,10 +71,12 @@ sub  apply ($$){
   my $minlen = (  length( $victim->{_str} ) >  length( $victim2->{_str} ) )?
 	 length( $victim2->{_str} ): length( $victim->{_str} );
   my $pt1 = int( rand( $minlen ) );
-  my $range = 1 + int( rand( $minlen  - $pt1 ) );
+  my $range;
 #  print "Puntos: $pt1, $range \n";
   if ( $self->{_numPoints} > 1 ) {
-    $range =  int ( rand( length( $victim->{_str} ) - $pt1 ) );
+    $range= 1 + int( rand( $minlen  - $pt1 ) );
+  } else {
+    $range = $minlen - $pt1 +1;
   }
   my $str = $victim->{_str};
   substr( $victim->{_str}, $pt1, $range ) = substr( $victim2->{_str}, $pt1, $range );
@@ -89,10 +91,10 @@ sub  apply ($$){
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 08:46:59 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/QuadXOver.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
+  CVS Info: $Date: 2010/01/17 17:49:54 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/QuadXOver.pm,v 3.1 2010/01/17 17:49:54 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.0 $
+  $Revision: 3.1 $
   $Name $
 
 =cut
